@@ -1,38 +1,38 @@
 $VAR1 = {
-          'language' => 'en',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'cgi' => {
-                     'serverName' => 'http://localhost',
-                     'expires' => '+1y',
-                     'cookiePath' => '/',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'title' => 'MySQL::Admin',
-                     'style' => 'mysql',
-                     'bin' => '/var/www/cgi-bin',
-                     'alias' => 'cgi-bin'
-                   },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'database' => {
-                          'CurrentUser' => 'root',
-                          'CurrentDb' => 'LZE',
-                          'CurrentPass' => 'wertvoll',
-                          'CurrentHost' => 'localhost',
-                          'user' => 'root',
-                          'host' => 'localhost',
-                          'name' => 'LZE',
-                          'password' => 'wertvoll'
-                        },
-          'version' => '0.66',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
           'floodtime' => 10,
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'scriptAlias' => 'cgi-bin',
+          'cgi' => {
+                     'title' => 'MySQL::Admin',
+                     'bin' => '/var/www/cgi-bin',
+                     'alias' => 'cgi-bin',
+                     'cookiePath' => '/',
+                     'serverName' => 'http://localhost',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'style' => 'mysql',
+                     'expires' => '+1y'
+                   },
           'defaultAction' => 'showLogin',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'version' => '0.67',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'admin' => {
-                       'email' => 'dirk.lze@gmail.com',
                        'firstname' => 'Dirk',
+                       'email' => 'dirk.lze@gmail.com',
                        'name' => 'Lindner',
                        'password' => 'testpass'
-                     }
+                     },
+          'database' => {
+                          'name' => 'LZE',
+                          'CurrentUser' => 'root',
+                          'CurrentHost' => 'localhost',
+                          'password' => 'wertvoll',
+                          'user' => 'root',
+                          'host' => 'localhost',
+                          'CurrentPass' => 'wertvoll',
+                          'CurrentDb' => 'LZE'
+                        },
+          'language' => 'en',
+          'config' => '/var/www/cgi-bin/config/settings.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
