@@ -1,8 +1,8 @@
 function init(){
 	loadPage('xml/action.xml','xsl/action.xsl','tab');
 	loadPage('xml/action.xml','xsl/menu.xsl','menu');
-	requestURI('/cgi-bin/mysql.pl?action=showDatabases&amp;ajax=true','showDatabases','Datenbanken');
-	translate();  
+	loadHistory();
+	translate();
 }
 function alert(txt){
 	visible('popup');
@@ -36,12 +36,12 @@ function checkForm(form){
     var regexp = selectElement[i].dataset.regexp;
     if(regexp){
       if(eval('value.match('+regexp+')')){
-	    selectElement[i].style.borderColor ='green';
-	    selectElement[i].title = selectElement[i].dataset.right;
+	  selectElement[i].style.borderColor ='green';
+	  selectElement[i].title = selectElement[i].dataset.right;
       }else{
-	selectElement[i].style.borderColor ='red';
-	selectElement[i].title = selectElement[i].dataset.error;
-	ret = false;
+	  selectElement[i].style.borderColor ='red';
+	  selectElement[i].title = selectElement[i].dataset.error;
+	  ret = false;
       }
     }
     }
@@ -121,8 +121,7 @@ function loadPage(inXml,inXsl,outId,tabId,title){
   	}
 	if(tabId && title)
 		setCurrentTab(tabId,title);
-	// evalId('login2');
-	// evalId('menuBar');
+
 	if (navigator.userAgent.indexOf("Firefox")!=-1 && inXml.indexOf(".xml") ==-1)
 		$('content').innerHTML = $('content').textContent;
 }
@@ -136,8 +135,8 @@ function markInput(bool){
        var body  = document.getElementsByTagName("body")[0];
        var node = body.getElementsByTagName("input");
        for(var i=0,j=node.length; i<j; i++)
-       if(node[i].className == 'markBox')    node[i].checked = bool;
-
+       if(node[i].className == 'markBox') 
+	 node[i].checked = bool;
        visible (bool ? 'umarkAll' : 'markAll' );
        hide (bool ? 'markAll' : 'umarkAll' );
 }
@@ -145,8 +144,8 @@ function markTables(bool){
        var body  = document.getElementsByTagName("body")[0];
        var node = body.getElementsByTagName("option");
        for(var i=0,j=node.length; i<j; i++)
-       if(node[i].className == 'table')    node[i].selected = bool;
-
+       if(node[i].className == 'table') 
+	 node[i].selected = bool;
        visible (bool ? 'umarkAll2' : 'markAll2' );
        hide (bool ? 'markAll2' : 'umarkAll2' );
 }
@@ -237,18 +236,15 @@ function submitForm(node,tabId,tabTitle){
 	}
 }
 var http_request = false;
-var oldpage,oldleft,oldright;
+var oldpage;
 function requestURI(url,id,txt,bHistory){
 	hide('popup');
 	bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
 	if(bHistory)
 	  history.pushState(null, '','?'+url);
 	var waid = getText('animationContainer');
-	oldleft = getText('leftSidebar');
 	oldpage = '';
 	oldpage = getText('content');
-	oldright = '';
-	oldright = getText('rightSidebar');
 	var w = '<div class="waid" >'+waid+'</div>';
 	setText('content',w);
 
@@ -256,9 +252,8 @@ function requestURI(url,id,txt,bHistory){
 
         if (window.XMLHttpRequest) { //Firefox
             http_request = new XMLHttpRequest();
-            if (http_request.overrideMimeType) {
+            if (http_request.overrideMimeType)
                 http_request.overrideMimeType('text/xml');
-            }
         } else if (window.ActiveXObject) { //IE
             try {
                 http_request = new ActiveXObject("Msxml2.XMLHTTP");
@@ -268,12 +263,10 @@ function requestURI(url,id,txt,bHistory){
                 } catch (e) {}
             }
         }
-	if($(id)){
-		setCurrentTab(id,txt);			
-	}else{
-		setCurrentTab('dynamicLink',txt);
-			
-	}
+	if($(id))
+	  setCurrentTab(id,txt);			
+	else
+	  setCurrentTab('dynamicLink',txt);	
         http_request.onreadystatechange = setContent;
         http_request.open('GET', url, true);
         http_request.send(null);
@@ -299,47 +292,17 @@ function loadXMLDoc(filename){
 function setContent() {
         if (http_request.readyState == 4) {
            if (http_request.status == 200) {
-            var response      = http_request.responseXML;
-
-	    var menuBar = response.getElementById('menuBar');
-	    if(menuBar){
-	      var lefttxt = menuBar.innerHTML;
-	      lefttxt = lefttxt.replace("<![CDATA[", "").replace("]]>", "");
-	      setText('menuBar',lefttxt);
-	    }
-	    var login = response.getElementById('login');
-	    if(login){
-	      var logintxt = login.innerHTML;
-	      logintxt = logintxt.replace("<![CDATA[", "").replace("]]>", "");
-	      setText('login',logintxt);
-	    }
-            var cont = response.getElementById('content');
-	    if(cont){
-	      var txt = cont.innerHTML;
-	      txt = txt.replace("<![CDATA[", "").replace("]]>", "");
-	      setText('content',txt);
-	    }else{
-	      if (window.ActiveXObject || xhttp.responseType == "msxml-document"){
-		ex = xml.transformNode(xsl);
-		$(id).innerHTML = ex;
-	      }else if (document.implementation && document.implementation.createDocument){//opera
-		xsltProcessor = new XSLTProcessor();
-		xsl = loadXMLDoc('/xsl/content.xsl');
-		xsltProcessor.importStylesheet(xsl);
-		resultDocument = xsltProcessor.transformToFragment(response, document);
-		node = $('content');
-		if(node.childNodes[0])
-			node.removeChild(node.childNodes[0]);
-		if(node)
-			node.appendChild(resultDocument);
+	      response      = http_request.responseXML;
+	      for(var i = 0; i < response.getElementsByTagName('output').length; i++){
+		var outID = response.getElementsByTagName('output')[i].getAttribute('id')
+		var txt  = response.getElementsByTagName('output')[i].textContent;
+		if (navigator.userAgent.indexOf("Firefox")!=-1)
+		    txt = txt.replace("<![CDATA[", "").replace("]]>", "");
+		setText(outID,txt);
 	      }
-	    }
-	    evalId("content");
-	
+	      evalId("content");
 	   }else{
 		setText('content',oldpage);
-		setText('leftSidebar',oldleft);
-		setText('rightSidebar',oldright);
 		setCurrentTab(currentId, currentTxt);
 	  }
         }
@@ -366,7 +329,10 @@ function loadHistory(){
 	var rxObj2 =  new RegExp(/(\?[^\?]+$)/);
 	rxObj2.exec(window.location.search);
 	var uri = RegExp.$1;
-	requestURI('/cgi-bin/mysql.pl'+uri,action,translate(action),false);
+	if(uri && action)
+	  requestURI('/cgi-bin/mysql.pl'+uri,action,translate(action),false);
+	else
+	  requestURI('/cgi-bin/mysql.pl?action=showDatabases','showDatabases','Datenbanken');
 }
 function translate(string){
 	var lng = navigator.language.indexOf("de") > -1 ? 'de':'en';
@@ -393,4 +359,4 @@ if (navigator.userAgent.indexOf("Firefox")!=-1)
 }
 function $(id){
     return document.getElementById(id);
-}
\ No newline at end of file
+}
